@@ -28,10 +28,11 @@ example_metadata = {
     ],
 }
 
-example_data = pd.DataFrame([{"field1": "test"}, {"field1": "test2", "field2": 9}])
+exacmple_record = {"field1": "test", "field2": 999}
 
 
-def test(token):
+def test(token, test_rows=10):
+    example_data = pd.DataFrame([exacmple_record] * test_rows)
     timestamp = datetime.datetime.now().strftime("%Y%m%d%H%M%S")
     tablename = "test_%s_%d" % (timestamp, random.randint(100000, 999999))
     cl = OepClient(token=token, tablename=tablename)
@@ -41,7 +42,8 @@ def test(token):
         cl.update_metadata(metadata=example_metadata)
         data = cl.download_data()
         metadata = cl.download_metadata()
-        print(data)
+        print(len(data))
+        print(data[0])
         print(metadata)
     finally:
         cl.delete()
